{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_list %}

{% block title %}{{ title }} | Django Control Room{% endblock %}

{% block extrahead %}
{{ block.super }}
{% if dj_cr_load_default_css %}<link rel="stylesheet" href="{% static 'dj_control_room/css/styles.css' %}">{% endif %}
{{ dj_cr_extra_css }}
{% endblock %}

{% block branding %}
<h1 id="site-name"><a href="{% url 'dj_control_room:index' %}">Django Control Room</a></h1>
{% endblock %}


{% block messages %}
{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; {% trans 'DJ Control Room' %}
</div>
{% endblock %}

{% block content %}
{% endblock %}
